treeInteractions: Tree Interactions

Description Usage Arguments Details Value

View source: R/treeInteractions.R

Description

Extract interactions fitted in an XGBoost model.

Usage

1
treeInteractions(in.tree, in.depth)

Arguments

in.tree

Trees from a fitted XGBoost model

in.depth

Maximum depth of the input model

Details

Search the trees of an XGBoost model to identify fitted interactions. For tree based models, interactions are modelled by features sharing the same tree. Pads out lower order interactions that are contained within a higher order interaction.

Value

Returns a list of vectors where each item of the list contains the feature names of one interaction.


BlueTea88/xgboostcon documentation built on May 17, 2019, 11:05 a.m.