treeNormalise: Tree Normalise

Description Usage Arguments Details

View source: R/treeNormalise.R

Description

Normalise tree conditions

Usage

1
treeNormalise(in.conditions, in.data, in.weights = NULL)

Arguments

in.conditions

feature conditions of trees, extracted using treeConditions()

in.data

training data used to fit the model in the form of a data.table

in.weights

vector of weights corresponding to each observation of in.data, defaults to a vector of 1s

Details

Normalise tree conditions by padding out lower order effects and setting the values of lower order conditions based on the weighted mean. The distribution of features is obtained from in.data and in.weights.


BlueTea88/xgboostcon documentation built on May 17, 2019, 11:05 a.m.