treeRanks: Tree Ranks

Description Usage Arguments Value

View source: R/treeRanks.R

Description

Rank the importance of each parameter on an input dataset

Usage

1
treeRanks(in.conditions, in.data, in.weights = NULL)

Arguments

in.conditions

table of normalised tree conditions

in.data

input dataset to calculate ranks

in.weights

vector of weights corresponding to each observation of in.data, defaults to a vector of 1s

Value

A table of parameters and their associated importance score.


BlueTea88/xgboostcon documentation built on May 17, 2019, 11:05 a.m.