Description Usage Arguments Details Value
View source: R/treeInteractions.R
Extract interactions fitted in an XGBoost model.
1 | treeInteractions(in.tree, in.depth)
|
in.tree |
Trees from a fitted XGBoost model |
in.depth |
Maximum depth of the input model |
Search the trees of an XGBoost model to identify fitted interactions. For tree based models, interactions are modelled by features sharing the same tree. Pads out lower order interactions that are contained within a higher order interaction.
Returns a list of vectors where each item of the list contains the feature names of one interaction.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.