Description Usage Arguments Details
View source: R/treeNormalise.R
Normalise tree conditions
1 | treeNormalise(in.conditions, in.data, in.weights = NULL)
|
in.conditions |
feature conditions of trees, extracted using |
in.data |
training data used to fit the model in the form of a |
in.weights |
vector of weights corresponding to each observation of |
Normalise tree conditions by padding out lower order effects and setting the values of lower order conditions based
on the weighted mean. The distribution of features is obtained from in.data and in.weights.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.